@@ -424,8 +424,8 @@ else:
         print("Batch-2")
     import os
     path="C:\\Users\\"+os.getlogin()+"\\Desktop\\output.txt"
-    f=open(path,'w')   
-    f.write(s)
+    with open(path,'w') as f:  
+        f.write(s)
     f.close()
 '''
     try:
